Installation FAQ
================

Errors with "recompile with -fPIC" for FFTW
-------------------------------------------
Make sure you have installed FFTW with ``--enable-shared``. On Ubuntu, you will
also need to have ``libfftw3-dev`` installed.
